import { convertEnumArr } from "@/utils";
import { ProFormColumnsType } from "@ant-design/pro-components";

function formConfig(enumList?:any): ProFormColumnsType<{
    name: string;
    state: string;
}>[] {
    let templateTypeEnum = enumList?.TEMPLATE_TYPE?.values || []
    return [
        {
            title: '模板名称',
            dataIndex: 'templateName',
            formItemProps: {
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            }
        },
        {
            title: '充值模板类型',
            dataIndex: 'templateType',
            valueType: 'select',
            valueEnum:  convertEnumArr(templateTypeEnum),
            formItemProps: {
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            }
        },
        {
            title: '充值模板描述',
            dataIndex: 'templateDescription',
            valueType: 'textarea',
        },
        {
            title: '备注',
            dataIndex: 'remark',
            valueType: 'textarea',
        },
        {
            title: '充值档位配置',
            dataIndex: 'rechargeConfigList',
            valueType: 'formList',
            fieldProps: {
                // min:4,
                // max:4,
                creatorButtonProps: {
                    creatorButtonText:"添加一个配置"
                }
            },
            colProps: {
                span: 24
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [{
                        title: '价格',
                        dataIndex: 'price',
                        valueType: 'money',
                        width: "100%",
                        colProps: {
                            span: 6
                        }
                    },
                    {
                        title: '赠送',
                        dataIndex: 'gift',
                        valueType: 'digit',
                        width: "100%",
                        colProps: {
                            span: 6
                        }
                    },
                    {
                        title: '额外赠送',
                        dataIndex: 'extra',
                        valueType: 'digit',
                        width: "100%",
                        colProps: {
                            span: 6
                        }
                    },
                    {
                        title: '额外描述',
                        dataIndex: 'description',
                        width: "100%",
                        colProps: {
                            span: 6
                        }
                    },]
                }
            ]
        },
        {
            title: '激活当前模板',
            dataIndex: 'activateTemplate',
            valueType: 'switch',
            formItemProps: { layout: 'horizontal' },
            colProps: { offset: 19 }
        },
    ]
}

export default formConfig